@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.17   2016/09/28
+ * Version: 0.2   2016/10/05
  */
 
 #ifndef _SECURITY_CAITSITH_INTERNAL_H
@@ -42,7 +42,6 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 30)
 #include <linux/fs_struct.h>
 #endif
-#include <linux/proc_fs.h>
 #include <linux/hash.h>
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 33) && defined(CONFIG_SYSCTL_SYSCALL)
 #include <linux/sysctl.h>
@@ -52,33 +51,14 @@
 #include <linux/magic.h>
 #endif
 #include <stdarg.h>
-#include <asm/uaccess.h>
+#include <linux/uaccess.h>
 #include <net/sock.h>
 #include <net/af_unix.h>
 #include <net/ip.h>
 #include <net/ipv6.h>
 #include <net/udp.h>
 #include <linux/ctype.h>
-
-#ifndef __printf
-#define __printf(a,b) __attribute__((format(printf,a,b)))
-#endif
-#ifndef __packed
-#define __packed __attribute__((__packed__))
-#endif
-#ifndef bool
-#define bool _Bool
-#endif
-#ifndef false
-#define false 0
-#endif
-#ifndef true
-#define true 1
-#endif
-
-#ifndef __user
-#define __user
-#endif
+#include <linux/magic.h>
 
 #ifndef current_uid
 #define current_uid()   (current->uid)
@@ -105,10 +85,6 @@
 #define current_fsgid() (current->fsgid)
 #endif
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 9, 0)
-#define f_vfsmnt f_path.mnt
-#endif
-
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 38)
 
 /**
@@ -209,7 +185,7 @@ static inline void __list_del_entry(struct list_head *entry)
 #endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(4, 0, 0)
-#define d_backing_inode(upper) (upper)->d_inode
+#define d_backing_inode(upper) ((upper)->d_inode)
 #endif
 #if LINUX_VERSION_CODE < KERNEL_VERSION(3, 14, 0)
 #define d_is_dir(dentry) ({ struct inode *inode = d_backing_inode(dentry); \
@@ -239,8 +215,10 @@ enum cs_conditions_index {
 	CS_SELF_PID,             /* sys_getpid()   */
 	/* 10 */
 	CS_SELF_PPID,            /* sys_getppid()  */
-	CS_TASK_TYPE,            /* ((u8) task->cs_flags) &
-				    CS_TASK_IS_EXECUTE_HANDLER */
+	CS_TASK_TYPE,            /*
+				  * ((u8) task->cs_flags) &
+				  *  CS_TASK_IS_EXECUTE_HANDLER
+				  */
 	CS_SELF_DOMAIN,
 	CS_SELF_EXE,
 	CS_EXEC_ARGC,            /* "struct linux_binprm *"->argc */
@@ -510,8 +488,8 @@ enum cs_policy_stat_type {
 	CS_MAX_POLICY_STAT
 } __packed;
 
-/* Index numbers for /proc/caitsith/ interfaces. */
-enum cs_proc_interface_index {
+/* Index numbers for /sys/kernel/security/caitsith/ interfaces. */
+enum cs_securityfs_interface_index {
 	CS_POLICY,
 	CS_PROCESS_STATUS,
 	CS_AUDIT,
@@ -573,7 +551,10 @@ enum cs_value_type {
 #define CS_TASK_IS_IN_EXECVE             4
 /* Current thread is running as an execute handler program? */
 #define CS_TASK_IS_EXECUTE_HANDLER       8
-/* Current thread is allowed to modify policy via /proc/caitsith/ interface? */
+/*
+ * Current thread is allowed to modify policy via
+ * /sys/kernel/security/caitsith/ interface?
+ */
 #define CS_TASK_IS_MANAGER              16
 
 /*
@@ -585,7 +566,7 @@ enum cs_value_type {
  */
 #define CS_RETRY_REQUEST 1
 
-/* Size of read buffer for /proc/caitsith/ interface. */
+/* Size of read buffer for /sys/kernel/security/caitsith/ interface. */
 #define CS_MAX_IO_READ_QUEUE 64
 
 /* Structure definition for internal use. */
@@ -796,7 +777,10 @@ struct cs_name {
 	struct cs_path_info entry;
 };
 
-/* Structure for reading/writing policy via /proc/caitsith/ interfaces. */
+/*
+ * Structure for reading/writing policy via /sys/kernel/security/caitsith/
+ * interfaces.
+ */
 struct cs_io_buffer {
 	/* Exclusive lock for this structure.   */
 	struct mutex io_sem;
@@ -840,7 +824,7 @@ struct cs_io_buffer {
 	/* Size of write buffer.                */
 	size_t writebuf_size;
 	/* Type of interface. */
-	enum cs_proc_interface_index type;
+	enum cs_securityfs_interface_index type;
 	/* Users counter protected by cs_io_buffer_list_lock. */
 	u8 users;
 	/* List for telling GC not to kfree() elements. */
@@ -966,6 +950,7 @@ static inline void cs_tasklist_unlock(void)
 static inline pid_t cs_sys_getppid(void)
 {
 	pid_t pid;
+
 	rcu_read_lock();
 	pid = task_tgid_vnr(rcu_dereference(current->real_parent));
 	rcu_read_unlock();
@@ -1093,6 +1078,7 @@ static inline struct cs_security *cs_current_security(void)
 static inline struct cs_domain_info *cs_task_domain(struct task_struct *task)
 {
 	struct cs_domain_info *domain;
+
 	rcu_read_lock();
 	domain = cs_find_task_security(task)->cs_domain_info;
 	rcu_read_unlock();
@@ -1119,6 +1105,7 @@ static inline struct cs_domain_info *cs_current_domain(void)
 static inline u32 cs_task_flags(struct task_struct *task)
 {
 	u32 cs_flags;
+
 	rcu_read_lock();
 	cs_flags = cs_find_task_security(task)->cs_flags;
 	rcu_read_unlock();
@@ -1157,6 +1144,7 @@ static inline u32 cs_current_flags(void)
 static inline struct cs_security *cs_current_security(void)
 {
 	struct task_struct *task = current;
+
 	if (!task->cs_domain_info)
 		task->cs_domain_info = &cs_kernel_domain;
 	return task;
@@ -1172,6 +1160,7 @@ static inline struct cs_security *cs_current_security(void)
 static inline struct cs_domain_info *cs_task_domain(struct task_struct *task)
 {
 	struct cs_domain_info *domain = task->cs_domain_info;
+
 	return domain ? domain : &cs_kernel_domain;
 }
 
