@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.17   2016/09/28
+ * Version: 0.2   2016/10/05
  */
 
 #include "internal.h"
@@ -16,9 +16,6 @@
 
 /***** SECTION3: Prototype definition section *****/
 
-struct cs_security *cs_find_task_security(const struct task_struct *task);
-void __init cs_mm_init(void);
-
 static int cs_alloc_task_security(const struct task_struct *task);
 static void cs_free_task_security(const struct task_struct *task);
 static void cs_add_task_security(struct cs_security *ptr,
@@ -58,6 +55,7 @@ static void cs_add_task_security(struct cs_security *ptr,
 				 struct list_head *list)
 {
 	unsigned long flags;
+
 	spin_lock_irqsave(&cs_task_security_list_lock, flags);
 	list_add_rcu(&ptr->list, list);
 	spin_unlock_irqrestore(&cs_task_security_list_lock, flags);
@@ -105,7 +103,8 @@ struct cs_security *cs_find_task_security(const struct task_struct *task)
 	struct list_head *list = &cs_task_security_list
 		[hash_ptr((void *) task, CS_TASK_SECURITY_HASH_BITS)];
 	/* Make sure INIT_LIST_HEAD() in cs_mm_init() takes effect. */
-	while (!list->next);
+	while (!list->next)
+		;
 	rcu_read_lock();
 	list_for_each_entry_rcu(ptr, list, list) {
 		if (ptr->task != task)
@@ -140,6 +139,7 @@ struct cs_security *cs_find_task_security(const struct task_struct *task)
 static void cs_rcu_free(struct rcu_head *rcu)
 {
 	struct cs_security *ptr = container_of(rcu, typeof(*ptr), rcu);
+
 	kfree(ptr);
 }
 
@@ -154,6 +154,7 @@ static void cs_free_task_security(const struct task_struct *task)
 {
 	unsigned long flags;
 	struct cs_security *ptr = cs_find_task_security(task);
+
 	if (ptr == &cs_default_security || ptr == &cs_oom_security)
 		return;
 	spin_lock_irqsave(&cs_task_security_list_lock, flags);
@@ -170,6 +171,7 @@ static void cs_free_task_security(const struct task_struct *task)
 void __init cs_mm_init(void)
 {
 	int idx;
+
 	for (idx = 0; idx < CS_MAX_TASK_SECURITY_HASH; idx++)
 		INIT_LIST_HEAD(&cs_task_security_list[idx]);
 	smp_wmb(); /* Avoid out of order execution. */
