@@ -437,7 +437,7 @@ static int cs_file_open(struct file *f, const struct cred *cred)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_chown(const struct path *path, kuid_t user, kgid_t group)
+static int cs_path_chown(struct path *path, kuid_t user, kgid_t group)
 {
 	return cs_chown_permission(path, user, group);
 }
@@ -450,7 +450,7 @@ static int cs_path_chown(const struct path *path, kuid_t user, kgid_t group)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_chmod(const struct path *path, umode_t mode)
+static int cs_path_chmod(struct path *path, umode_t mode)
 {
 	return cs_chmod_permission(path, mode);
 }
@@ -462,7 +462,7 @@ static int cs_path_chmod(const struct path *path, umode_t mode)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_chroot(const struct path *path)
+static int cs_path_chroot(struct path *path)
 {
 	return cs_chroot_permission(path);
 }
@@ -474,7 +474,7 @@ static int cs_path_chroot(const struct path *path)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_truncate(const struct path *path)
+static int cs_path_truncate(struct path *path)
 {
 	return cs_truncate_permission(path);
 }
@@ -531,7 +531,7 @@ static int cs_inode_getattr(const struct path *path)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_mknod(const struct path *dir, struct dentry *dentry,
+static int cs_path_mknod(struct path *dir, struct dentry *dentry,
 			 umode_t mode, unsigned int dev)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
@@ -548,7 +548,7 @@ static int cs_path_mknod(const struct path *dir, struct dentry *dentry,
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_mkdir(const struct path *dir, struct dentry *dentry,
+static int cs_path_mkdir(struct path *dir, struct dentry *dentry,
 			 umode_t mode)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
@@ -564,7 +564,7 @@ static int cs_path_mkdir(const struct path *dir, struct dentry *dentry,
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_rmdir(const struct path *dir, struct dentry *dentry)
+static int cs_path_rmdir(struct path *dir, struct dentry *dentry)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
 
@@ -579,7 +579,7 @@ static int cs_path_rmdir(const struct path *dir, struct dentry *dentry)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_unlink(const struct path *dir, struct dentry *dentry)
+static int cs_path_unlink(struct path *dir, struct dentry *dentry)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
 
@@ -595,7 +595,7 @@ static int cs_path_unlink(const struct path *dir, struct dentry *dentry)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_symlink(const struct path *dir, struct dentry *dentry,
+static int cs_path_symlink(struct path *dir, struct dentry *dentry,
 			   const char *old_name)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
@@ -613,10 +613,8 @@ static int cs_path_symlink(const struct path *dir, struct dentry *dentry,
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_rename(const struct path *old_dir,
-			  struct dentry *old_dentry,
-			  const struct path *new_dir,
-			  struct dentry *new_dentry)
+static int cs_path_rename(struct path *old_dir, struct dentry *old_dentry,
+			  struct path *new_dir, struct dentry *new_dentry)
 {
 	struct path old = { .mnt = old_dir->mnt, .dentry = old_dentry };
 	struct path new = { .mnt = new_dir->mnt, .dentry = new_dentry };
@@ -633,7 +631,7 @@ static int cs_path_rename(const struct path *old_dir,
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_path_link(struct dentry *old_dentry, const struct path *new_dir,
+static int cs_path_link(struct dentry *old_dentry, struct path *new_dir,
 			struct dentry *new_dentry)
 {
 	struct path old = { .mnt = new_dir->mnt, .dentry = old_dentry };
@@ -1125,8 +1123,7 @@ static void cs_inode_free_security(struct inode *inode)
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_sb_pivotroot(const struct path *old_path,
-			   const struct path *new_path)
+static int cs_sb_pivotroot(struct path *old_path, struct path *new_path)
 {
 	return cs_pivot_root_permission(old_path, new_path);
 }
@@ -1142,7 +1139,7 @@ static int cs_sb_pivotroot(const struct path *old_path,
  *
  * Returns 0 on success, negative value otherwise.
  */
-static int cs_sb_mount(const char *dev_name, const struct path *path,
+static int cs_sb_mount(const char *dev_name, struct path *path,
 		       const char *type, unsigned long flags, void *data_page)
 {
 	return cs_mount_permission(dev_name, path, type, flags, data_page);
